@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from collections import OrderedDict
 import re
 
-from mogwai._compat import string_types
+from mogwai._compat import string_types, print_, add_metaclass
 from mogwai.tools import import_string
 from mogwai import properties
 from mogwai.exceptions import MogwaiException, SaveStrategyException, \
@@ -10,6 +10,10 @@ from mogwai.exceptions import MogwaiException, SaveStrategyException, \
 from mogwai.gremlin import BaseGremlinMethod
 from mogwai.connection import _add_model_to_space
 
+# import for backward compatibility
+from mogwai.constants import BOTH, EQUAL, GREATER_THAN, GREATER_THAN_EQUAL, \
+    IN, LESS_THAN, LESS_THAN_EQUAL, NOT_EQUAL, OUT
+
 
 import logging
 import warnings
@@ -19,20 +23,6 @@ logger = logging.getLogger(__name__)
 vertex_types = {}
 edge_types = {}
 
-# in blueprints this is part of the Query.compare
-# see http://www.tinkerpop.com/docs/javadocs/blueprints/2.2.0/
-EQUAL = "EQUAL"
-GREATER_THAN = "GREATER_THAN"
-GREATER_THAN_EQUAL = "GREATER_THAN_EQUAL"
-LESS_THAN = "LESS_THAN"
-LESS_THAN_EQUAL = "LESS_THAN_EQUAL"
-NOT_EQUAL = "NOT_EQUAL"
-
-# direction
-OUT = "OUT"
-IN = "IN"
-BOTH = "BOTH"
-
 
 class BaseElement(object):
     """
@@ -70,22 +60,29 @@ class BaseElement(object):
         """
         self._id = values.get('_id')
         self._values = {}
-        #print "Received values: %s" % values
-        #print "Known Relationships: %s" % self._relationships
+        self._manual_values = {}
+        #print_("Received values: %s" % values)
+        #print_("Known Relationships: %s" % self._relationships)
         for name, prop in self._properties.items():
-            #print "trying name: %s in values" % name,
+            #print_("trying name: %s in values" % name)
             value = values.get(name, None)
             if value is not None:
-                #print "Got value"
+                #print_("Got value")
                 value = prop.to_python(value)
             #else:
-                #print "no value found"
+                #print_("no value found")
             value_mngr = prop.value_manager(prop, value, prop.save_strategy)
             self._values[name] = value_mngr
             setattr(self, name, value)
         for name, relationship in self._relationships.items():
             relationship._setup_instantiated_vertex(self)
 
+        # unknown properties that are loaded manually
+        from mogwai.properties.base import BaseValueManager
+        for kwarg in set(values.keys()).difference(set(self._properties.keys())):  # set(self._properties.keys()) - set(values.keys()):
+            if kwarg not in ('_id', '_inV', '_outV', 'element_type'):
+                self._manual_values[kwarg] = BaseValueManager(None, values.get(kwarg))
+
     @property
     def id(self):
         return self._id
@@ -150,12 +147,17 @@ class BaseElement(object):
     def validate(self):
         """Cleans and validates the field values"""
         for name in self._properties.keys():
+            #print_("Validating {}...".format(name))
             func_name = 'validate_{}'.format(name)
             val = getattr(self, name)
+            #print_("Got {}: func_name: {}, attr: {} ({})".format(name, func_name, val, type(val)))
             if hasattr(self, func_name):
+                #print_("Calling custom function: {}".format(func_name))
                 val = getattr(self, func_name)(val)
             else:
+                #print_("Calling standard function: {}".format(self._properties[name]))
                 val = self._properties[name].validate(val)  # self.validate_field(name, val)
+            #print_("Validated {}: val: {} ({}), func_name: {}".format(name, val, type(val), func_name))
             setattr(self, name, val)
 
     def as_dict(self):
@@ -168,6 +170,7 @@ class BaseElement(object):
         values = {}
         for name, prop in self._properties.items():
             values[name] = prop.to_database(getattr(self, name, None))
+        values.update(self._manual_values)
         return values
 
     def as_save_params(self):
@@ -193,9 +196,24 @@ class BaseElement(object):
                                                   graph_property=prop)
 
             if should_save:
-                #print "Saving %s to database for name %s" % (prop.db_field_name or name, name)
+                #print_("Saving %s to database for name %s" % (prop.db_field_name or name, name))
                 values[prop.db_field_name or name] = prop.to_database(vm.value)
 
+        # manual values
+        for name, prop in self._manual_values.items():
+            if prop is None:
+                # Remove this property entirely
+                values[name] = None
+            else:
+                # Determine the save strategy
+                prop_strategy = prop.strategy
+                if prop_strategy.condition(previous_value=prop.previous_value,
+                                           value=prop.value,
+                                           has_changed=prop.changed,
+                                           first_save=was_saved,
+                                           graph_property=None):
+                    values[name] = prop.value
+
         return values
 
     @classmethod
@@ -211,9 +229,9 @@ class BaseElement(object):
         dst_data = data.copy().get('_properties', {})
         if data.get('_id', None):
             dst_data.update({'_id': data.copy().get('_id')})
-        #print "Raw incoming data: %s" % data
+        #print_("Raw incoming data: %s" % data)
         for name, prop in cls._properties.items():
-            #print "trying db_field_name: %s and name: %s" % (prop.db_field_name, name)
+            #print_("trying db_field_name: %s and name: %s" % (prop.db_field_name, name))
             if prop.db_field_name in dst_data:
                 dst_data[name] = dst_data.pop(prop.db_field_name)
             elif name in dst_data:
@@ -307,6 +325,87 @@ class BaseElement(object):
         
         return create_cls
 
+    def __getitem__(self, item):
+        logger.debug("Using __getitem__({})...".format(item))
+        #print_("Using __getitem__({})...: options: _properties({}), _manual_values({})".format(item, self._properties.items(), self._manual_values.items()))
+        value = self._properties.get(item, None)
+        if value is not None:
+            # call the normal getattr method
+            return getattr(self, item)
+        else:
+            # manual entry
+            value_manager = self._manual_values.get(item, None)
+            """ :type value_manager: mogwai.properties.base.BaseValueManager | None """
+            if value_manager is None:
+                raise AttributeError(item)
+            return value_manager.value
+
+    def __setitem__(self, key, value):
+        logger.debug("Using __setitem__({}): {}...".format(key, value))
+        prop = self._properties.get(key, None)
+        if prop is not None:
+            # call the normal setattr method
+            setattr(self, key, value)
+        else:
+            # manual entry
+            if key in self._manual_values:
+                # manual entry already exists, update
+                self._manual_values[key].setval(value)
+            else:
+                # manual entry doesn't exist, create
+                from mogwai.properties.base import BaseValueManager
+                self._manual_values[key] = BaseValueManager(None, value)
+
+    def __delitem__(self, key):
+        logger.debug("Using __delitem__({})...".format(key))
+        prop = self._properties.get(key, None)
+        if prop is not None:
+            # call the normal delattr method
+            delattr(self, key)
+        else:
+            # manual entry
+            if key in self._manual_values:
+                # manual entry already exists, update for delete
+                self._manual_values[key] = None
+            else:
+                raise AttributeError(key)
+
+    def __contains__(self, item):
+        logger.debug("Checking contains...")
+        return item in set(self._properties.keys()).union(set(self._manual_values.keys()))
+
+    def __len__(self):
+        logger.debug("Getting len...")
+        return len(set(self._properties.keys()).union(set(self._manual_values.keys())))
+
+    def __iter__(self):
+        logger.debug("Iterating through __iter__...")
+        for item in set(self._properties.keys()).union(set(self._manual_values.keys())):
+            yield item
+
+    def items(self):
+        logger.debug("Iterating through items...")
+        items = []
+        for key in self._properties.keys():
+            items.append((key, getattr(self, key)))
+        items.extend([(pair[0], pair[1].value) for pair in self._manual_values.items() if pair[1] is not None])
+        return items
+
+    def keys(self):
+        logger.debug("Iterating through keys...")
+        items = []
+        items.extend(self._properties.keys())
+        items.extend([k for k in self._manual_values.keys() if self._manual_values.get(k) is not None])
+        return items
+
+    def values(self):
+        logger.debug("Iterating through values...")
+        items = []
+        for key in self._properties.keys():
+            items.append(getattr(self, key))
+        items.extend([v.value for v in self._manual_values.values() if v is not None])
+        return items
+
 
 class ElementMetaClass(type):
     """Metaclass for all graph elements"""
@@ -328,7 +427,7 @@ class ElementMetaClass(type):
             for k, v in getattr(base, '_relationships', {}).items():
                 relationship_dict.setdefault(k, v)
 
-        #print "Name: %s\n\tBases: %s\n\tBody: %s" % (name, bases, body.keys())
+        #print_("Name: %s\n\tBases: %s\n\tBody: %s" % (name, bases, body.keys()))
 
         def _transform_property(prop_name, prop_obj):
             prop_dict[prop_name] = prop_obj
@@ -346,7 +445,8 @@ class ElementMetaClass(type):
                 body[prop_name] = property(_get, _set)
 
         property_definitions = [(k, v) for k, v in body.items() if isinstance(v, properties.GraphProperty)]
-        property_definitions = sorted(property_definitions, lambda x, y: cmp(x[1].position, y[1].position))
+        property_definitions = sorted(property_definitions, #cmp=lambda x, y: cmp(x[1].position, y[1].position),
+                                      key=lambda x: x[1].position)
 
         #TODO: check that the defined graph properties don't conflict with any of the
         #Model API's existing attributes/methods transform column definitions
@@ -420,8 +520,9 @@ class ElementMetaClass(type):
         return klass
 
 
+@add_metaclass(ElementMetaClass)
 class Element(BaseElement):
-    __metaclass__ = ElementMetaClass
+    #__metaclass__ = ElementMetaClass
 
     @classmethod
     def deserialize(cls, data):
@@ -447,4 +548,4 @@ class Element(BaseElement):
             return edge_types[edge_type](data['_outV'], data['_inV'], **translated_data)
 
         else:
-            raise TypeError("Can't deserialize '%s'" % dtype)
\ No newline at end of file
+            raise TypeError("Can't deserialize '%s'" % dtype)
