@@ -19,9 +19,9 @@ class GraphPropertyBaseClassTestCase(BaseMogwaiTestCase):
 
     def test_validation(self):
         for case in self.good_cases:
-            print_("testing good case: %s" % (case, ))
+            print_("testing good case: {}".format(case))
             self.assertNotRaise(self.klass().validate, case)
 
         for case in self.bad_cases:
-            print_("testing bad case: %s" % (case, ))
+            print_("testing bad case: {}".format(case))
             self.assertRaises(ValidationError, self.klass().validate, case)
