@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 from nose.plugins.attrib import attr
-from base_tests import GraphPropertyBaseClassTestCase
+from .base_tests import GraphPropertyBaseClassTestCase
 from mogwai.properties.properties import List
 from mogwai.models import Vertex
 from mogwai._compat import print_
@@ -9,8 +9,8 @@ from mogwai._compat import print_
 @attr('unit', 'property', 'property_list')
 class ListPropertyTestCase(GraphPropertyBaseClassTestCase):
     klass = List
-    good_cases = ([], ['val'], (), tuple('val'))
-    bad_cases = (0, 1.1, None, 'val', {}, {'value': 1})
+    good_cases = ([], ['val'], (), tuple('val'), None)
+    bad_cases = (0, 1.1, 'val', {}, {'value': 1})
 
 
 class ListTestVertex(Vertex):
